import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3'; // Importing the 'arc' function from 'd3' library

const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;
const eyeOffsetX = 90;
const eyeOffsetY = 100;
const eyeRadius = 40;
const mouthWidth = 10;
const mouthRadius = 120;

// Creating an arc generator for the mouth
const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI * 0.75 + 3 / 2) // Start angle of the mouth arc
  .endAngle((Math.PI * 2) / 2.8); // End angle of the mouth arc

// React component for the cartoon face
const App = () => {
  const [message, setMessage] = useState('');

  useEffect(() => {
    const csvUrl =
      'https://gist.githubusercontent.com/akhilcharugulla/56150d0d98677cf8b511530e34f71a77/raw/3e0cfff900b00630ad3cf0547ba7d514262e353c/cars_cleaned.csv';
    fetch(csvUrl)
      .then((response) => response.text())
      .then((csvText) => {
        const rows = csvText.split('\n');
        const rowCount = rows.length - 1; // Exclude header row
        const columnCount = rows[0].split(',').length;

        const message =
          'Below is the data for colours:\n' +
          Math.round(csvText.length / 1024) +
          ' kB\n' +
          rowCount +
          ' rows\n' +
          'and ' +
          columnCount +
          ' columns';

        setMessage(message);
      })
      .catch((error) =>
        console.error('Error fetching CSV:', error),
      );
  }, []);

  return (
    <>
      <h1>Hii People</h1>
      <div style={styles.container}>
        <h1 style={styles.heading}>This is the CSV Data</h1>
        <p style={styles.paragraph}>{message}</p>
      </div>
      <h2>This is my svg</h2>
      <svg width={width} height={height}>
        <g transform={`translate(${centerX},${centerY})`}>
          {/* Hair */}
          <ellipse
            cx={0}
            cy={-centerY + 50} // Adjusted position for hair
            rx={centerX - 100} // Adjusted horizontal radius for hair
            ry={50} // Vertical radius for hair
            fill="brown" // Color of the hair
          />
          {/* Pellets */}
          <circle
            cx={-100}
            cy={-100}
            r={10}
            fill="orange"
          />
          <circle cx={0} cy={-100} r={10} fill="orange" />
          <circle cx={100} cy={-100} r={10} fill="orange" />
          {/* Ears */}
          <ellipse
            cx={eyeOffsetX + 120} // Adjusted position for the right ear
            cy={-eyeOffsetY + 20} // Adjusted position for the right ear
            rx={40} // Adjusted horizontal radius for the ears
            ry={70} // Adjusted vertical radius for the ears
            fill="pink" // Color of the ears
          />
          <ellipse
            cx={-eyeOffsetX - 120} // Adjusted position for the left ear
            cy={-eyeOffsetY + 20} // Adjusted position for the left ear
            rx={40} // Adjusted horizontal radius for the ears
            ry={70} // Adjusted vertical radius for the ears
            fill="pink" // Color of the ears
          />
          {/* Body */}
          <circle
            r={centerY - strokeWidth / 2}
            fill="violet" // Color of the body
            stroke="black"
            strokeWidth={strokeWidth}
          />
          {/* Eyes */}
          <circle
            cx={eyeOffsetX}
            cy={-eyeOffsetY}
            r={eyeRadius / 2}
            fill="black" // Color of the eyes
            stroke="black"
          />
          <circle
            cx={-eyeOffsetX}
            cy={-eyeOffsetY}
            r={eyeRadius / 2}
            fill="black" // Color of the eyes
            stroke="black"
          />
          {/* Glasses */}
          <ellipse
            cx={eyeOffsetX}
            cy={-eyeOffsetY}
            rx={eyeRadius}
            ry={eyeRadius / 1.5}
            fill="none"
            stroke="black" // Color of the glasses
            strokeWidth={5}
          />
          <ellipse
            cx={-eyeOffsetX}
            cy={-eyeOffsetY}
            rx={eyeRadius}
            ry={eyeRadius / 1.5}
            fill="none"
            stroke="black" // Color of the glasses
            strokeWidth={5}
          />
          {/* Mouth */}
          <path d={mouthArc()} fill="none" stroke="black" />
          {/* Mustache */}
          <path
            d={`M${-eyeOffsetX},${-eyeOffsetY + 30}
              C${-eyeOffsetX - 20},${-eyeOffsetY + 20} ${eyeOffsetX + 20},${-eyeOffsetY + 20} ${eyeOffsetX},${-eyeOffsetY + 30}`}
            fill="none"
            stroke="black"
            strokeWidth="4"
          />
          {/* Cheeks */}
          <circle
            cx={eyeOffsetX - 60}
            cy={-eyeOffsetY + 20}
            r={20}
            fill="pink" // Color of the cheeks
          />
          <circle
            cx={-eyeOffsetX + 60}
            cy={-eyeOffsetY + 20}
            r={20}
            fill="pink" // Color of the cheeks
          />
          {/* Teeth */}
          <rect
            x={-30}
            y={120}
            width={20}
            height={40}
            fill="white" // Color of the teeth
          />
          <rect
            x={10}
            y={120}
            width={20}
            height={40}
            fill="white" // Color of the teeth
          />
          {/* Beard */}
          <path
            d={`M${-eyeOffsetX - 30},${-eyeOffsetY + 60}
              Q${-eyeOffsetX - 10},${-eyeOffsetY + 100} 0,${-eyeOffsetY + 150}
              Q${eyeOffsetX + 10},${-eyeOffsetY + 100} ${eyeOffsetX + 30},${-eyeOffsetY + 60}`}
            fill="none"
            stroke="black"
            strokeWidth="4"
          />
        </g>
      </svg>
    </>
  );
};

const styles = {
  container: {
    backgroundColor: '#f0f0f0',
    padding: '20px',
    textAlign: 'center',
    fontFamily: 'Arial, sans-serif',
  },
  heading: {
    fontSize: '40px',
    marginBottom: '10px',
    color: 'green',
  },
  paragraph: {
    fontSize: '25px',
    color: 'blue',
  },
};

// Rendering the App component
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
